@@ -3,14 +3,14 @@ import os
 from typing import Optional
 import requests
 
-from obiguard.api_resources.global_constants import OBIGUARD_TRACE_URL
+from obiguard.api_resources.global_constants import OBIGUARD_BASE_URL
 
 
 class Logger:
     def __init__(
         self, api_key: Optional[str] = None, base_url: Optional[str] = None
     ) -> None:
-        api_key = api_key or os.getenv("PORTKEY_API_KEY")
+        api_key = api_key or os.getenv("OBIGUARD_API_KEY")
         if api_key is None:
             raise ValueError("API key is required to use the Logger API")
 
