@@ -11,7 +11,7 @@ from obiguard.api_resources.base_client import APIClient, AsyncAPIClient
 from .utils import base_url_to_instrumentation_url, traceparent_from_span
 from .._vendor.openai import OpenAI, AsyncOpenAI
 from obiguard.api_resources.global_constants import (
-    OPEN_AI_API_KEY, OBIGUARD_ADDITIONAL_HEADERS_KEY, OBIGUARD_BASE_URL,
+    OPEN_AI_API_KEY, OBIGUARD_ADDITIONAL_HEADERS_KEY, OBIGUARD_GATEWAY_URL,
 )
 from obiguard_trace_python_sdk import langtrace
 from opentelemetry import baggage, context, trace
@@ -109,14 +109,13 @@ class Obiguard(APIClient):
         # Init opentelemetry setup
         langtrace.init(
             api_key=obiguard_api_key,
-            api_host=instrumentation_url or base_url_to_instrumentation_url(base_url or OBIGUARD_BASE_URL),
+            api_host=instrumentation_url or base_url_to_instrumentation_url(base_url or OBIGUARD_GATEWAY_URL),
             session_id=run_id,
             service_name='obiguard.python.service',
             disable_logging=False,
             baggage_attributes={'obiguard.run_id': run_id}
         )
 
-        # Create the root span first before the custom headers
         with trace.get_tracer(__name__).start_as_current_span(
                 identifier or f'Run #{run_id}',
                 kind=SpanKind.CLIENT,
