@@ -7,7 +7,8 @@ from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 
 from .crewai import CrewAIInstrumentor
 from .litellm import LitellmInstrumentor
-from .portkey_span_exporter import PortkeySpanExporter
+from .obiguard_span_exporter import ObiguardSpanExporter
+
 # from .langgraph import LanggraphInstrumentor
 
 __all__ = ["initialize_instrumentation"]
@@ -29,7 +30,7 @@ def is_package_installed(pkg_name):
 
 def initialize_instrumentation(api_key: str, base_url: str):
     tracer_provider = TracerProvider()
-    exporter = PortkeySpanExporter(api_key=api_key, base_url=base_url)
+    exporter = ObiguardSpanExporter(api_key=api_key, base_url=base_url)
     tracer_provider.add_span_processor(BatchSpanProcessor(exporter))
     trace.set_tracer_provider(tracer_provider)
     for package, instrumentor in package_instrumentor_map.items():
